class rob:
    def scared():
        lol = "Rob (the dev of the api) is scared that i will upload this module"
        return lol
    def hot():
        idkanymore = "Rob is veri hot and seggsy"
        return idkanymore


import random
import requests

def fact():
    randomnumber = random.randint(1, 26)
    r = requests.get("https://api.hentaihaven.dev/factapi.json").json()
    factlol = r[f"{randomnumber}"]
    return factlol


import setuptools

f = open("readme.md")
descriptionlol = f.read()

setuptools.setup(
name="hentaihavenpy",
version="0.2",
author="hentaihaven.edu",
description="haha hentai api go brrrrrrrrr cumshot in my ass",
long_description=descriptionlol,
long_description_content_type="text/markdown",
url="https://hentaihaven.dev",
package_dir={"": "hentaihavenpy"},
packages=setuptools.find_packages(where="hentaihavenpy"),
install_requires=["requests"]
)